Run
Date: 2015-08-04

jep

## Class Run

- java.lang.Object
- - jep.Run

-     public class Run
      extends java.lang.Object

  Executes a Python script in a Jep sub-interpreter.

- - ### Method Summary

    Methods
    Modifier and Type | Method and Description
    --- | ---
    `static void` | `main(java.lang.String[] args)` Describe `main` method here.
    `static int` | `run(boolean eventDispatch)`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

- - ### Method Detail

    - #### run

          public static int run(boolean eventDispatch)

    - #### main

          public static void main(java.lang.String[] args)
                           throws java.lang.Throwable

      Describe `main` method here.
      Parameters:
        `args` - a `String` value
      Throws:
        `java.lang.Throwable` - if an error occurs
        `java.lang.Exception` - if an error occurs